@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: crypto-api
 version: 0.13.2
-id: crypto-api-0.13.2-095d0cf567bb83558b8b8ae881dd04fd
-key: crypt_Kp4uvZbywBzKttuHrlYBAx
+id: crypto-api-0.13.2-6578ff0df46f6893eafa074007e52b3d
+key: crypt_2BEYKdRP8nrKGHynW1FWqA
 license: BSD3
 copyright: Thomas DuBuisson <thomas.dubuisson@gmail.com>
 maintainer: Thomas DuBuisson <thomas.dubuisson@gmail.com>
@@ -31,13 +31,13 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-api-0.13.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/crypto-api-0.13.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/crypto-api-0.13.2
-hs-libraries: HScrypto-api-0.13.2-Kp4uvZbywBzKttuHrlYBAx
+hs-libraries: HScrypto-api-0.13.2-2BEYKdRP8nrKGHynW1FWqA
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     cereal-0.5.1.0-2c7be146776a4abf674d1ac9e0ccfc13
     entropy-0.3.7-db9feabff8921cc1dd6e8db21278a74f
-    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
+    tagged-0.8.4-af2e23230031c45949e0062e776a8f1f
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
 haddock-interfaces: /usr/share/doc/haskell-crypto-api/html/crypto-api.haddock
 haddock-html: /usr/share/doc/haskell-crypto-api/html
